@@ -30,6 +30,7 @@
 #include "nact-editor.h"
 #include "nact-utils.h"
 #include "nact-prefs.h"
+#include "nact.h"
 
 enum {
 	ICON_STOCK_COLUMN = 0,
@@ -239,7 +240,7 @@ static GtkTreeModel* create_stock_icon_model (void)
 	GSList* iter;
 	GtkListStore* model;
 	GtkTreeIter row;
-	GtkWidget* window = nact_get_glade_widget_from ("EditActionDialog", GLADE_EDIT_DIALOG_WIDGET);
+	//GtkWidget* window = nact_get_glade_widget_from ("EditActionDialog", GLADE_EDIT_DIALOG_WIDGET);
 	GtkStockItem stock_item;
 	gchar* label;
 
@@ -318,7 +319,10 @@ static void fill_menu_icon_combo_list_of (GtkComboBoxEntry* combo)
 	GtkCellRenderer *cell_renderer_text;
 	
 	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), create_stock_icon_model ());
-	gtk_combo_box_entry_set_text_column (combo, ICON_STOCK_COLUMN);
+	if (gtk_combo_box_entry_get_text_column (combo) == -1)
+	{
+		gtk_combo_box_entry_set_text_column (combo, ICON_STOCK_COLUMN);
+	}
 	gtk_cell_layout_clear (GTK_CELL_LAYOUT (combo));
 
 	cell_renderer_pix = gtk_cell_renderer_pixbuf_new ();
@@ -475,7 +479,7 @@ static void create_schemes_selection_list (void)
 	GSList* schemes_list = nact_prefs_get_schemes_list ();
 	GtkListStore* model;
 	GtkTreeIter row;
-	gchar* label;
+	//gchar* label;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer* toggled_cell;
 	GtkCellRenderer* text_cell;
@@ -601,43 +605,60 @@ static void set_action_schemes (gchar* action_scheme, GtkTreeModel* scheme_model
 	}
 }
 
-static void set_action_basenames_list (GtkEntry* entry, GSList* basenames)
+static void set_action_match_string_list (GtkEntry* entry, GSList* basenames, const gchar* default_string)
 {
 	GSList* iter;
 	gchar* entry_text;
 	gchar* tmp;
 
 	iter = basenames;
-	entry_text = g_strdup ((gchar*)iter->data);
-	iter = iter->next;
-	
-	while (iter)
+	if (!iter)
 	{
-		tmp = g_strjoin (" ; ", entry_text, (gchar*)iter->data, NULL);
-		g_free (entry_text);
-		entry_text = tmp;
+		entry_text = g_strdup (default_string);
+	}
+	else
+	{
+		entry_text = g_strdup ((gchar*)iter->data);
 		iter = iter->next;
+	
+		while (iter)
+		{
+			tmp = g_strjoin (" ; ", entry_text, (gchar*)iter->data, NULL);
+			g_free (entry_text);
+			entry_text = tmp;
+			iter = iter->next;
+		}
 	}
 
 	gtk_entry_set_text (entry, entry_text);
 }
 
-static GSList* get_action_basenames_list (const gchar* patterns)
+static GSList* get_action_match_string_list (const gchar* patterns, const gchar* default_string)
 {
-	gchar** tokens = g_strsplit (patterns, ";", -1);
+	gchar** tokens;
 	gchar** iter;
 	GSList* list = NULL;
 	gchar* tmp;
-	
-	iter = tokens;
-	while (*iter != NULL)
+
+	tmp = g_strstrip (patterns);
+	if (strlen (tmp) == 0)
 	{
-		tmp = g_strstrip (*iter);
-		list = g_slist_append (list, g_strdup (tmp));
-		iter++;
+		list = g_slist_append (list, g_strdup (default_string));
+	}
+	else
+	{
+		tokens = g_strsplit (patterns, ";", -1);
+		
+		iter = tokens;
+		while (*iter != NULL)
+		{
+			tmp = g_strstrip (*iter);
+			list = g_slist_append (list, g_strdup (tmp));
+			iter++;
+		}
+		
+		g_strfreev (tokens);
 	}
-	
-	g_strfreev (tokens);
 
 	return list;
 }
@@ -658,7 +679,7 @@ open_editor (NautilusActionsConfigAction *action, gboolean is_new)
 	GtkSizeGroup* button_size_group;
 	GtkWidget *menu_icon, *scheme_listview;
 	GtkWidget *menu_label, *menu_tooltip;
-	GtkWidget *command_path, *command_params, *test_patterns;
+	GtkWidget *command_path, *command_params, *test_patterns, *match_case, *test_mimetypes;
 	GtkWidget *only_files, *only_folders, *both, *accept_multiple;
 	gint width, height, x, y;
 	GtkTreeModel* scheme_model;
@@ -693,6 +714,12 @@ open_editor (NautilusActionsConfigAction *action, gboolean is_new)
 		{
 			gtk_size_group_add_widget (label_size_group, GTK_WIDGET (iter->data));
 		}
+		aligned_widgets = nact_get_glade_widget_prefix_from ("CLabelAlign", GLADE_EDIT_DIALOG_WIDGET);
+		label_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+		for (iter = aligned_widgets; iter; iter = iter->next)
+		{
+			gtk_size_group_add_widget (label_size_group, GTK_WIDGET (iter->data));
+		}
 		button_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 		gtk_size_group_add_widget (button_size_group, 
 											nact_get_glade_widget_from ("IconBrowseButton", 
@@ -749,7 +776,13 @@ open_editor (NautilusActionsConfigAction *action, gboolean is_new)
 	gtk_entry_set_text (GTK_ENTRY (command_params), action->parameters);
 
 	test_patterns = nact_get_glade_widget_from ("PatternEntry", GLADE_EDIT_DIALOG_WIDGET);
-	set_action_basenames_list (GTK_ENTRY (test_patterns), action->basenames);
+	set_action_match_string_list (GTK_ENTRY (test_patterns), action->basenames, "*");
+
+	match_case = nact_get_glade_widget_from ("MatchCaseButton", GLADE_EDIT_DIALOG_WIDGET);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (match_case), action->match_case);
+
+	test_mimetypes = nact_get_glade_widget_from ("MimeTypeEntry", GLADE_EDIT_DIALOG_WIDGET);
+	set_action_match_string_list (GTK_ENTRY (test_mimetypes), action->mimetypes, "*/*");
 
 	only_folders = nact_get_glade_widget_from ("OnlyFoldersButton", GLADE_EDIT_DIALOG_WIDGET);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (only_folders), action->is_dir);
@@ -782,11 +815,19 @@ open_editor (NautilusActionsConfigAction *action, gboolean is_new)
 		nautilus_actions_config_action_set_path (action, gtk_entry_get_text (GTK_ENTRY (command_path)));
 		nautilus_actions_config_action_set_parameters (action, gtk_entry_get_text (GTK_ENTRY (command_params)));
 
-		list = get_action_basenames_list (gtk_entry_get_text (GTK_ENTRY (test_patterns)));
+		list = get_action_match_string_list (gtk_entry_get_text (GTK_ENTRY (test_patterns)), "*");
 		nautilus_actions_config_action_set_basenames (action, list);
 		g_slist_foreach (list, (GFunc) g_free, NULL);
 		g_slist_free (list);
 
+		nautilus_actions_config_action_set_match_case (
+			action, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (match_case)));
+		
+		list = get_action_match_string_list (gtk_entry_get_text (GTK_ENTRY (test_mimetypes)), "*/*");
+		nautilus_actions_config_action_set_mimetypes (action, list);
+		g_slist_foreach (list, (GFunc) g_free, NULL);
+		g_slist_free (list);
+
 		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (only_files))) {
 			nautilus_actions_config_action_set_is_file (action, TRUE);
 			nautilus_actions_config_action_set_is_dir (action, FALSE);
